@@ -610,6 +610,12 @@ class TestAsyncClient(unittest.TestCase):
         c._trigger_event.mock.assert_called_once_with(
             'message', {'foo': 'bar'}, run_async=True)
 
+    def test_receive_close_packet(self):
+        c = asyncio_client.AsyncClient()
+        c.disconnect = AsyncMock()
+        _run(c._receive_packet(packet.Packet(packet.CLOSE)))
+        c.disconnect.mock.assert_called_once_with(abort=True)
+
     def test_send_packet_disconnected(self):
         c = asyncio_client.AsyncClient()
         c.queue = c.create_queue()
@@ -1063,7 +1069,7 @@ class TestAsyncClient(unittest.TestCase):
         c._send_request.mock.assert_called_once_with(
             'POST', 'http://foo', body=p.encode(),
             headers={'Content-Type': 'application/octet-stream'})
-        self.assertEqual(c.state, 'disconnected')
+        self.assertEqual(c.state, 'connected')
 
     def test_write_loop_polling_bad_connection(self):
         c = asyncio_client.AsyncClient()
@@ -1165,6 +1171,28 @@ class TestAsyncClient(unittest.TestCase):
         self.assertEqual(c.ws.send.mock.call_args_list[1][0][0], '2')
         self.assertEqual(c.ws.send.mock.call_args_list[2][0][0], '6')
 
+    def test_write_loop_websocket_one_packet_binary(self):
+        c = asyncio_client.AsyncClient()
+        c.state = 'connected'
+        c.ping_interval = 1
+        c.ping_timeout = 2
+        c.current_transport = 'websocket'
+        c.queue = mock.MagicMock()
+        c.queue.Empty = RuntimeError
+        c.queue.get = AsyncMock(side_effect=[
+            packet.Packet(packet.MESSAGE, b'foo'),
+            RuntimeError
+        ])
+        c.queue.get_nowait = mock.MagicMock(side_effect=[
+            RuntimeError
+        ])
+        c.ws = mock.MagicMock()
+        c.ws.send = AsyncMock()
+        _run(c._write_loop())
+        self.assertEqual(c.queue.task_done.call_count, 1)
+        self.assertEqual(c.ws.send.mock.call_count, 1)
+        c.ws.send.mock.assert_called_once_with(b'\x04foo')
+
     def test_write_loop_websocket_bad_connection(self):
         c = asyncio_client.AsyncClient()
         c.state = 'connected'
